@@ -49,7 +49,6 @@ class Response(object):
         self._body_iter = body_iter or iter([])
 
     def __iter__(self):
-        print('hoge')
         return self._body_iter
 
     def iter_content(self):
@@ -58,7 +57,7 @@ class Response(object):
 
     @property
     def content(self):
-        return ''.join([chunk for chunk in self._body_iter])
+        return b''.join([chunk for chunk in self._body_iter])
 
 
 def get_swift_connection():
@@ -432,7 +431,7 @@ class StorletMagics(Magics):
         # invoke storlet app on copy
         conn = get_swift_connection()
         response_dict = dict()
-        with open(args.input, 'r') as content:
+        with open(args.input, 'rb') as content:
             conn.put_object(
                 dst_container, dst_obj,
                 content,
